@@ -3,12 +3,12 @@
 from decimal import Decimal
 import operator
 from trytond.pool import Pool, PoolMeta
+from trytond.transaction import Transaction
 
 __all__ = ['InvoiceLine']
 
 
-class InvoiceLine:
-    __metaclass__ = PoolMeta
+class InvoiceLine(metaclass=PoolMeta):
     __name__ = 'account.invoice.line'
 
     @classmethod
@@ -58,6 +58,8 @@ class InvoiceLine:
             move_line.account = self.account
         else:
             move_line.account = self.product.account_cogs_used
+        if move_line.account.party_required:
+            move_line.party = self.invoice.party
         result.append(move_line)
         return result
 
@@ -115,6 +117,8 @@ class InvoiceLine:
             self.product, moves, abs(self.quantity), self.unit, type_)
         cost = self.invoice.currency.round(cost)
 
-        anglo_saxon_move_lines = self._get_anglo_saxon_move_lines(cost, type_)
+        with Transaction().set_context(date=accounting_date):
+            anglo_saxon_move_lines = self._get_anglo_saxon_move_lines(
+                cost, type_)
         result.extend(anglo_saxon_move_lines)
         return result
